@@ -6,15 +6,17 @@ use warnings;
 
 =head1 NAME
 
-CLI::Files::Utils - File bunch utilies 'dirhier' and 'madeafter' to supplement the functionality of the "ls" and "find" commands.
+CLI::Files::Utils - Extra CLI utilies for handling file bunches.
+'dirhier', 'madeafter' and 'colorplus -3' -- Utilize them after mastering "ls -l" and "find .".
+
 
 =head1 VERSION
 
-Version 0.103
+Version 0.104
 
 =cut
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 
 =head1 SUPPORT
